Paper Figures
-------------

In the spirit of `reprodicible research <http://reproducibleresearch.net>`_,
this page lists the source code for figures from published papers which
use datasets and routines available in astroML.
